from typing import List
from flood_risk.config import HOURLY_PLUVIO_FLOOD_RISK_FOLDER

def create_partial_pluvio(latest_pluvio_data_paths: List[str], current_date: str) -> str:
    import numpy as np
    import os
    from rasterio import open, float64
    print("latest hourly path", latest_pluvio_data_paths)
    for a in latest_pluvio_data_paths:
          print(a)
    print(current_date)
    output_dir = HOURLY_PLUVIO_FLOOD_RISK_FOLDER
    if not os.path.exists(output_dir):
        os.mkdir(output_dir)
    hourly_data = np.zeros((1, 256, 256))
    for path in latest_pluvio_data_paths:
        with open(path, 'r') as pl:
            new_data = pl.read()
            new_data = np.array(new_data).reshape([1,256,256])
            hourly_data = np.add(hourly_data, new_data)

    print("HOURLY DATA: ", str(hourly_data))
    latest_hourly_pluvio_filename = f"latest_hourly_pluvio.tif"
    latest_hourly_pluvio_filepath = os.path.join(output_dir, latest_hourly_pluvio_filename)
    print("LATEST HOURLY PLUVIO PATH ", latest_hourly_pluvio_filepath)
    with open(f"{latest_hourly_pluvio_filepath}", 'w', 
                width=256, height=256,
                dtype=float64,
                crs='EPSG:32632',
                count=1) as h_pl:
                    h_pl.write(hourly_data)
                    h_pl.update_tags(
                        timestamp=current_date
                    )
    return latest_hourly_pluvio_filepath


def run_mlm_flood_risk(model_path, hourly_pluvio_filepath, ndmi_local_filepath):
    import os
    import rasterio
    import tensorflow as tf
    import numpy as np
    width=256
    height=256
    print(model_path)
    #retrieve mlm model
    model = tf.keras.models.load_model(model_path, compile=False)

    #retrieve cumulated pluvio
    with rasterio.open(hourly_pluvio_filepath, 'r') as src:
                pluvio_image_data = src.read()
                pluvio_image_data = np.array(pluvio_image_data)
           
                pluvio_image_data= pluvio_image_data.reshape([256,256])
      
    #retrieve last ndmi
    with rasterio.open(ndmi_local_filepath, 'r') as src:
                ndmi_image_data = src.read()
                ndmi_image_data = np.array(ndmi_image_data)
      
                ndmi_image_data = ndmi_image_data.reshape([256,256])
     
                gcps=src.gcps[0]

    #create input tensor
    fake_channel = np.zeros((width, height)) #fake channel
    input_tensor = np.dstack((ndmi_image_data, pluvio_image_data, fake_channel))

    input_tensor = input_tensor.reshape([1,256,256,3])
    #run mlm
    result = model.predict(input_tensor)

    result_array = np.array(result[0])
    max_index = np.argmax(result_array)

    risk_value="L"
    if(max_index==0):  
        risk_value="L"
    if(max_index==1):  
        risk_value="M"
    if(max_index==2):  
        risk_value="H"
    return risk_value

    #save temp result as new predicted ndmi
    # if not os.path.exists(destination_folder):
    #     os.mkdir(destination_folder)
    # with rasterio.open(f"{destination_folder}/{timestamp}.tif", 'w',
    #     width=256, height=256,
    #     dtype=rasterio.float64,
    #     transform=rasterio.transform.from_gcps(gcps),
    #     crs='EPSG:32632',
    #     count=1) as r:
    #         r.write(predictions)
    #         r.update_tags(
    #             timestamp=timestamp,
    #             AREA_OR_POINT='Area'
    #         )

    