from ndmi_prediction.config import AIRFLOW_NDMI_FOLDER, ARTYS_LATEST_NDMI_FOLDER, AIRFLOW_MODELS_FOLDER, NDMI_MODEL_NAME, AIRFLOW_PREDICTED_NDMI_FOLDER

def save_ndmi_on_hf(destination_folder, search_keyword, repo_id):
    import os
    from huggingface_hub import HfApi
    from airflow.models import Variable
    from ndmi_prediction.config import AUTH_TOKEN

    hf_api = HfApi(
    token=AUTH_TOKEN
    )
    file_list = os.listdir(destination_folder)

    for file_name in file_list:
        if search_keyword in file_name:
            update_config_json_file_on_hf(file_name, "filelist.json", repo_id, destination_folder) #update configuration on hf
            update_config_py_file_on_hf(file_name, "filelist.py", repo_id, destination_folder) #update configuration on hf
            destination_path = os.path.join(destination_folder, file_name)
            hf_api.upload_file(
                path_or_fileobj=destination_path,
                path_in_repo=file_name,
                repo_id=repo_id,
                repo_type='dataset'
            )
            

def update_config_json_file_on_hf(item_name, filename, repo_id, file_path):
    import json
    from huggingface_hub import hf_hub_download
    from airflow.models import Variable
    from huggingface_hub import HfApi
    from ndmi_prediction.config import AUTH_TOKEN
    
    hf_api = HfApi(
    token=AUTH_TOKEN
    )
    hf_hub_download(repo_id=repo_id, filename=filename, repo_type="dataset", local_dir=file_path, token=AUTH_TOKEN)
    
    with open(file_path+"/"+filename, 'r') as json_file:
        data = json.load(json_file)
        data.append(item_name)

    with open(file_path+"/"+filename, 'w') as json_file:
        json.dump(data, json_file, indent=4)

    hf_api.upload_file(
    path_or_fileobj=file_path+"/"+filename,
    path_in_repo=filename,
    repo_id=repo_id,
    repo_type="dataset",
    )

def update_config_py_file_on_hf(item_name, filename, repo_id, file_path):
    import json, os
    from huggingface_hub import hf_hub_download
    from airflow.models import Variable
    from huggingface_hub import HfApi
    from ndmi_prediction.config import AUTH_TOKEN
    
    hf_api = HfApi(token=AUTH_TOKEN)
    hf_hub_download(repo_id=repo_id, filename=filename, repo_type="dataset", local_dir=file_path, token=AUTH_TOKEN)

    with open(os.path.join(file_path, filename), 'r') as py_file:
        data = py_file.read().replace("\n", "")
        data = data.split(" = ")[1]
        print("DATA ", data)
        data = data.replace("'", '"')
        print("DATA W APEX ", data)
        data = json.loads(data)
        item_name_no_ext = os.path.splitext(item_name)[0]
        if item_name_no_ext not in data: 
            data.append(item_name_no_ext)
            print("DATA WITH NEW EL ", data) 

    with open(os.path.join(file_path, filename), 'w') as py_file:
        # format data to be written in file up to before last element
        data = ["\t'" + x + "', \n" for x in data]
        # remove last comma to make possible json serialization/deserialization
        data[-1] = data[-1].replace(",", "")
        print("FORMAT DATA ", data)
        py_file.write("CONFIGS = [\n")
        py_file.writelines(data)
        py_file.write("]")

    hf_api.upload_file(
        path_or_fileobj=os.path.join(file_path, filename),
        path_in_repo=filename,
        repo_id=repo_id,
        repo_type="dataset",
    )
    
def save_latest_cumulated_pluvio_hf(source_file_path: str, filename: str) -> None:
    import os
    from huggingface_hub import HfApi
    from airflow.models import Variable
    from ndmi_prediction.config import AUTH_TOKEN

    HF_H_CUM_PLUVIO_DS = Variable.get("HF_H_CUM_PLUVIO_DS")
    hf_api = HfApi( token=AUTH_TOKEN )

    #upload file into the repository
    hf_api.upload_file(
        path_or_fileobj=source_file_path,
        path_in_repo=filename,
        repo_id=HF_H_CUM_PLUVIO_DS,
        repo_type='dataset'
    )